<?php
if (!class_exists('GNA_Slack_Settings_Menu')) {
	class GNA_Slack_Settings_Menu extends GNA_Slack_Admin_Menu {
		var $menu_page_slug = 'gna-sn-settings-menu';

		/* Specify all the tabs of this menu in the following array */
		var $menu_tabs;

		var $menu_tabs_handler = array(
			'tab1' => 'render_tab1',
			'tab2' => 'render_tab2',
			);

		public function __construct() {
			$this->render_menu_page();
		}

		public function set_menu_tabs() {
			$this->menu_tabs = array(
				'tab1' => __('Webhook Settings', 'gna-slack-notification'),
				//'tab2' => __('Incoming Settings', 'gna-slack-notification'),
			);
		}

		public function get_current_tab() {
			$tab_keys = array_keys($this->menu_tabs);
			$tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $tab_keys[0];
			return $tab;
		}

		/*
		 * Renders our tabs of this menu as nav items
		 */
		public function render_menu_tabs() {
			$current_tab = $this->get_current_tab();

			echo '<h2 class="nav-tab-wrapper">';
			foreach ( $this->menu_tabs as $tab_key => $tab_caption ) 
			{
				$active = $current_tab == $tab_key ? 'nav-tab-active' : '';
				echo '<a class="nav-tab ' . $active . '" href="?page=' . $this->menu_page_slug . '&tab=' . $tab_key . '">' . $tab_caption . '</a>';
			}
			echo '</h2>';
		}

		/*
		 * The menu rendering goes here
		 */
		public function render_menu_page() {
			echo '<div class="wrap">';
			echo '<h2>'.__('Settings','gna-slack-notification').'</h2>';//Interface title
			$this->set_menu_tabs();
			$tab = $this->get_current_tab();
			$this->render_menu_tabs();
			?>
			<div id="poststuff"><div id="post-body">
			<?php 
				//$tab_keys = array_keys($this->menu_tabs);
				call_user_func(array(&$this, $this->menu_tabs_handler[$tab]));
			?>
			</div></div>
			</div><!-- end of wrap -->
			<?php
		}

		public function render_tab1() {
			global $g_slack;
			if ( isset($_POST['gna_sn_save_settings']) ) {
				$nonce = $_REQUEST['_wpnonce'];
				if ( !wp_verify_nonce($nonce, 'n_gna-sn-save-settings') ) {
					die("Nonce check failed on save settings!");
				}

				$g_slack->configs->set_value('g_webhook_url_ipt', isset($_POST["g_webhook_url_ipt"]) ? $_POST["g_webhook_url_ipt"] : '');

				$g_slack->configs->set_value('g_channel_name', isset($_POST["g_channel_name"]) ? array_map('strtolower', str_replace('#', '', $_POST["g_channel_name"])) : '');
				$g_slack->configs->set_value('g_bot_name', isset($_POST["g_bot_name"]) ? $_POST["g_bot_name"] : '');
				$g_slack->configs->set_value('g_emoji_name', isset($_POST["g_emoji_name"]) ? $_POST["g_emoji_name"] : '');
				$g_slack->configs->set_value('g_events_notify', isset($_POST["g_events_notify"]) ? $_POST["g_events_notify"] : '');
				$g_slack->configs->set_value('g_channel_notice', isset($_POST["g_channel_notice"]) ? $_POST["g_channel_notice"] : '');
				$g_slack->configs->set_value('g_activated', isset($_POST["g_activated"]) ? $_POST["g_activated"] : '');
				$g_slack->configs->save_config();
				$this->show_msg_settings_updated();
			}
			?>
			<div class="postbox">
				<h3 class="hndle"><label for="title"><?php _e('GNA Slack Notification', 'gna-slack-notification'); ?></label></h3>
				<div class="inside">
					<p><?php _e('Thank you for using our GNA Slack Notification plugin.', 'gna-slack-notification'); ?></p>
				</div>
			</div>

			<form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
				<?php wp_nonce_field('n_gna-sn-save-settings'); ?>
				<?php
					$webhook_url = $g_slack->configs->get_value('g_webhook_url_ipt');
				?>
				<div class="gna_blue_box">
					<ol>
						<li>
							<?php
								_e('Webhook URL:', 'gna-slack-notification');
								echo '<p>'.__('Install "Incoming Webhooks App" and put its URL.', 'gna-slack-notification').'<br/><a href="https://slack.com/apps/A0F7XDUAZ-incoming-webhooks" target="_blank">https://slack.com/apps/A0F7XDUAZ-incoming-webhooks</a></p>';
							?>
						</li>
						<li>
							<?php
								_e('Channel:', 'gna-slack-notification');
								echo '<p>'.__('Channel in which notification will be sent to. For example <code>#general</code>.', 'gna-slack-notification').'</p>';
							?>
						</li>
						<li>
							<?php
								_e('Bot Name:', 'gna-slack-notification');
								echo '<p>'.__('Name of the bot that delivers the notification.', 'gna-slack-notification').'</p>';
							?>
						</li>
						<li>
							<?php
								_e('Emoji:', 'gna-slack-notification');
								echo '<p>'.__('Icon (short name) of the bot that delivers the notification. For available icon short name, see <a href="http://unicodey.com/emoji-data/table.htm" target="_blank">here</a>. Short name must be wrapped with colon, for instance <code>:rocket:</code>.', 'gna-slack-notification').'</p>';
							?>
						</li>
						<li>
							<?php
								_e('Events to Notify:', 'gna-slack-notification');
								echo '<p>'.__('Send a message when this event is happened.', 'gna-slack-notification').'</p>';
								echo '<p class="notice-error notice-alt">'.__('Login Lockdown is only working with "<a href="" target="_blank">All In One WP Security & Firewall</a>" plugin.', 'gna-slack-notification').'</p>';
							?>
						</li>
						<li>
							<?php
								_e('Channel Notice:', 'gna-slack-notification');
								echo '<p>'.__('Notify(alert) everyone in this channel if it is checked.', 'gna-slack-notification').'</p>';
							?>
						</li>
						<li>
							<?php
								_e('Activated:', 'gna-slack-notification');
								echo '<p>'.__('Notification will not be sent if not checked.', 'gna-slack-notification').'</p>';
							?>
						</li>
					</ol>
				</div>
				<div class="postbox">
					<h3 class="hndle"><label for="title"><?php _e('Webhook', 'gna-slack-notification'); ?></label></h3>
					<div class="inside">
						<div class="ipt_wrapper">
							<table class="form-table">
								<tr valign="top">
									<th scope="row"><?php _e('Webhook URL', 'gna-slack-notification'); ?>:</th>
									<td>
										<input type="url" class="webhook_url_ipt large-text" name="g_webhook_url_ipt[]" value="<?php echo $webhook_url[0]; ?>" />
									</td>
									<td class="delete_td">
										<button class="add_channel_button button"><?php _e('Add More', 'gna-slack-notification'); ?>
									</td>
								</tr>
							</table>
						</div>
					</div>
					<?php
						$channel_names = $g_slack->configs->get_value('g_channel_name');
						$bot_names = $g_slack->configs->get_value('g_bot_name');
						$emoji_names = $g_slack->configs->get_value('g_emoji_name');
						$events_notifies = $g_slack->configs->get_value('g_events_notify');
						$channel_notices = $g_slack->configs->get_value('g_channel_notice');
						$activated_arr = $g_slack->configs->get_value('g_activated');

						if ( isset($channel_names) && !empty($channel_names) ) {
							foreach ( $channel_names as $k => $channel_name ) {
					?>
					<div class="inside gna_grey_box">
						<div class="">
							<table class="form-table">
								<tr valign="top">
									<th scope="row"><?php _e('Channel', 'gna-slack-notification'); ?>:</th>
									<td>
										<input type="text" class="g_channel_name regular-text" name="g_channel_name[]" value="<?php echo $channel_names[$k]; ?>" required />
									</td>
								</tr>
								<tr valign="top">
									<th scope="row"><?php _e('Bot Name', 'gna-slack-notification'); ?>:</th>
									<td>
										<input type="text" class="g_bot_name regular-text" name="g_bot_name[]" value="<?php echo $bot_names[$k]; ?>" required />
									</td>
								</tr>
								<tr valign="top">
									<th scope="row"><?php _e('Emoji', 'gna-slack-notification'); ?>:</th>
									<td>
										<input type="text" class="g_emoji_name regular-text" name="g_emoji_name[]" value="<?php echo $emoji_names[$k]; ?>" required />
									</td>
								</tr>
								<tr valign="top">
									<th scope="row"><?php _e('Events to Notify', 'gna-slack-notification'); ?>:</th>
									<td>
										<?php echo GNA_Slack::generate_event_notify_dropdown($events_notifies[$k]); ?>
									</td>
								</tr>
								<tr valign="top">
									<th scope="row"><?php _e('Channel Notice', 'gna-slack-notification'); ?>:</th>
									<td>
										<?php echo GNA_Slack::generate_yesno_dropdown('g_channel_notice[]', $channel_notices[$k]); ?>
									</td>
								</tr>
								<tr valign="top">
									<th scope="row"><?php _e('Activated', 'gna-slack-notification'); ?>:</th>
									<td>
										<?php echo GNA_Slack::generate_yesno_dropdown('g_activated[]', $activated_arr[$k]); ?>
									</td>
								</tr>
							</table>
						</div>
						<button class="delete_channel_button button"><?php _e('Delete', 'gna-slack-notification'); ?></button>
					</div>
					<?php
							}
						}
					?>
				</div>
				<!--<button class="add_field_button button"><?php _e('Add More Webhook URL', 'gna-slack-notification'); ?></button>-->
				<input type="submit" name="gna_sn_save_settings" value="<?php _e('Save Settings', 'gna-slack-notification'); ?>" class="button button-primary" />
			</form>
			<?php
		}

		public function render_tab2() {
			global $g_slack;
			if ( isset($_POST['gna_sn_save_settings']) ) {
				$nonce = $_REQUEST['_wpnonce'];
				if ( !wp_verify_nonce($nonce, 'n_gna-sn-save-settings') ) {
					die("Nonce check failed on save settings!");
				}

				$g_slack->configs->set_value('g_webhook_url_ipt', isset($_POST["g_webhook_url_ipt"]) ? $_POST["g_webhook_url_ipt"] : '');
				$g_slack->configs->save_config();
				$this->show_msg_settings_updated();
			}
			?>
			<div class="postbox">
				<h3 class="hndle"><label for="title"><?php _e('GNA Slack Notification', 'gna-slack-notification'); ?></label></h3>
				<div class="inside">
					<p><?php _e('Thank you for using our GNA Slack Notification plugin.', 'gna-slack-notification'); ?></p>
				</div>
			</div>

			<form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
				<?php wp_nonce_field('n_gna-sn-save-settings'); ?>
				<?php
					$webhooks = $g_slack->configs->get_value('g_webhook_url_ipt');
					if( isset($webhooks) && is_array($webhooks) && !empty($webhooks) ) {
						foreach($webhooks as $webhook) {
				?>
				<div class="postbox">
					<h3 class="hndle"><label for="title"><?php _e('Webhook', 'gna-slack-notification'); ?></label></h3>
					<div class="inside">
						<div class="ipt_wrapper">
							<table class="form-table">
								<tr valign="top">
									<th scope="row"><?php _e('Webhook URL', 'gna-slack-notification'); ?>:</th>
									<td>
										<input type="url" class="webhook_url_ipt" name="g_webhook_url_ipt[]" value="<?php echo $webhook; ?>" />
									</td>
									<td class="delete_td"><button class="delete_field_button button"><?php _e('Delete', 'gna-slack-notification'); ?></button></td>
								</tr>
							</table>
						</div>
					</div>
				</div>
				<?php
						}
					}
				?>
				<button class="add_field_button button "><?php _e('Add More Webhook URL', 'gna-slack-notification'); ?></button>
				<input type="submit" name="gna_sn_save_settings" value="<?php _e('Save Settings', 'gna-slack-notification'); ?>" class="button button-primary" />
			</form>
			<?php
		}
	} //end class
}
