<?php
if (!class_exists('GNA_Slack')) {
	class GNA_Slack {
		var $plugin_url;
		var $admin_init;
		var $send_api;
		var $configs;
		public $events_notify_arr;
/*
		public function init() {
			$class = __CLASS__;
			new $class;
		}
*/
		public function __construct() {
			$this->load_configs();
			$this->define_constants();
			$this->define_variables();
			$this->includes();
			$this->loads();

			add_action('init', array(&$this, 'plugin_init'), 0);
			add_filter('plugin_row_meta', array(&$this, 'filter_plugin_meta'), 10, 2);
			
			add_action('wp_login', array(&$this, 'gna_user_login'), 99, 2);
			add_action('transition_post_status', array(&$this, 'on_all_status_transitions'), 10, 3);
			add_action('wp_insert_comment', array(&$this, 'comment_inserted'), 99, 2);
			add_action('aiowps_lockdown_event', array(&$this, 'gna_lockdown_event'), 99, 2);
		}

		public function load_configs() {
			include_once('inc/gna-slack-notification-config.php');
			$this->configs = GNA_Slack_Config::get_instance();
		}

		public function define_constants() {
			define('GNA_SLACK_NOTIFICATION_VERSION', '1.0.0');

			define('GNA_SLACK_NOTIFICATION_BASENAME', plugin_basename(__FILE__));
			define('GNA_SLACK_NOTIFICATION_URL', $this->plugin_url());

			define('GNA_SLACK_NOTIFICATION_MENU_SLUG_PREFIX', 'gna-sn-settings-menu');

			//For Events to Notify.
			define('GNA_SLACK_NOTIFICATION_LOGIN', 1);
			define('GNA_SLACK_NOTIFICATION_NEW_POST', 2);
			define('GNA_SLACK_NOTIFICATION_NEW_COMMENT', 3);
			define('GNA_SLACK_NOTIFICATION_LOGIN_LOCKDOWN', 4);
		}

		public function define_variables() {
		}

		public function includes() {
			if(is_admin()) {
				include_once('admin/gna-slack-notification-admin-init.php');
			}
			include_once('inc/gna-slack-send.php');
		}

		public function loads() {
			if(is_admin()){
				$this->admin_init = new GNA_Slack_Admin_Init();
				$this->send_api = new GNA_Slack_Send();
			}
		}

		public function plugin_init() {
			load_plugin_textdomain('gna-slack-notification', false, dirname(plugin_basename(__FILE__ )) . '/languages/');
		}

		public function plugin_url() {
			if ($this->plugin_url) return $this->plugin_url;
			return $this->plugin_url = plugins_url( basename( plugin_dir_path(__FILE__) ), basename( __FILE__ ) );
		}

		public function filter_plugin_meta($links, $file) {
			if( strpos( GNA_SLACK_NOTIFICATION_BASENAME, str_replace('.php', '', $file) ) !== false ) { /* After other links */
				$links[] = '<a target="_blank" href="https://profiles.wordpress.org/chris_dev/" rel="external">' . __('Developer\'s Profile', 'gna-slack-notification') . '</a>';
			}

			return $links;
		}

		public function gna_user_login($user_login) {
			global $g_slack;
			$channel_names = $g_slack->configs->get_value('g_channel_name');
			$bot_names = $g_slack->configs->get_value('g_bot_name');
			$emoji_names = $g_slack->configs->get_value('g_emoji_name');
			$events_notifies = $g_slack->configs->get_value('g_events_notify');
			$channel_notices = $g_slack->configs->get_value('g_channel_notice');
			$activated_arr = $g_slack->configs->get_value('g_activated');

			foreach ( $activated_arr as $k => $activated ) {
				if ( $activated == '1' && $events_notifies[$k] == GNA_SLACK_NOTIFICATION_LOGIN ) {
					$user = get_user_by('login', $user_login);
					
					// get the user ID 
					$user_id = $user->ID;

					// get the current site url 
					$site_url = get_bloginfo('wpurl');
					
					// prepare a message to be posted to slack 
					$message = $user_login . ' just logged in to ' . $site_url;

					if ( $channel_notices[$k] == '1' ) {
						$message = '<!channel|channel>: ' . $message;
					}

					GNA_Slack_Send::send_to_slack($message, $channel_names[$k], $bot_names[$k], $emoji_names[$k]);
				}
			}
		}

		function on_all_status_transitions( $new_status, $old_status, $post ) {
			global $g_slack;
			$channel_names = $g_slack->configs->get_value('g_channel_name');
			$bot_names = $g_slack->configs->get_value('g_bot_name');
			$emoji_names = $g_slack->configs->get_value('g_emoji_name');
			$events_notifies = $g_slack->configs->get_value('g_events_notify');
			$channel_notices = $g_slack->configs->get_value('g_channel_notice');
			$activated_arr = $g_slack->configs->get_value('g_activated');
			$site_url = get_bloginfo('wpurl');

			foreach ( $activated_arr as $k => $activated ) {
				if ( $activated == '1' && $events_notifies[$k] == GNA_SLACK_NOTIFICATION_NEW_POST ) {
					if ( $new_status != $old_status ) {
						if ( 'publish' !== $old_status && 'publish' === $new_status ) {
							$excerpt = has_excerpt( $post->ID ) ?
							apply_filters( 'get_the_excerpt', $post->post_excerpt )
							:
							wp_trim_words( strip_shortcodes( $post->post_content ), 55, '&hellip;' );

							$message = sprintf(
								'New post published: *<%1$s|%2$s>* by *%3$s* on %4$s' . "\n" .
								'> %5$s',

								get_permalink( $post->ID ),
								get_the_title( $post->ID ),
								get_the_author_meta( 'display_name', $post->post_author ),
								$site_url,
								$excerpt
							);

							if ( $channel_notices[$k] == '1' ) {
								$message = '<!channel|channel>: ' . $message;
							}

							GNA_Slack_Send::send_to_slack($message, $channel_names[$k], $bot_names[$k], $emoji_names[$k]);
						}
					}
				}
			}
		}
		
		function comment_inserted($comment_id, $comment_object) {
			//if ( $comment_object->comment_parent > 0 ) {
				global $g_slack;
				$channel_names = $g_slack->configs->get_value('g_channel_name');
				$bot_names = $g_slack->configs->get_value('g_bot_name');
				$emoji_names = $g_slack->configs->get_value('g_emoji_name');
				$events_notifies = $g_slack->configs->get_value('g_events_notify');
				$channel_notices = $g_slack->configs->get_value('g_channel_notice');
				$activated_arr = $g_slack->configs->get_value('g_activated');
				$site_url = get_bloginfo('wpurl');

				foreach ( $activated_arr as $k => $activated ) {
					if ( $activated == '1' && $events_notifies[$k] == GNA_SLACK_NOTIFICATION_NEW_COMMENT ) {
						$post_id = $comment_object->comment_post_ID;

						$post_title     = get_the_title( $post_id );
						$comment_status = wp_get_comment_status( $comment_id );

						$message = sprintf(
							'<%1$s|New comment> by *%2$s* on *<%3$s|%4$s>* (_%5$s_) of %6$s' . "\n" .
							'>%7$s',

							admin_url( "comment.php?c=$comment_id&action=editcomment" ),
							$comment_object->comment_author,
							get_permalink( $post_id ),
							$post_title,
							$comment_status,
							$site_url,
							preg_replace( "/\n/", "\n>", get_comment_text( $comment_id ) )
						);

						if ( $channel_notices[$k] == '1' ) {
							$message = '<!channel|channel>: ' . $message;
						}

						GNA_Slack_Send::send_to_slack($message, $channel_names[$k], $bot_names[$k], $emoji_names[$k]);
					}
				}
			//}
		}

		public function gna_lockdown_event($ip_range, $username) {
			global $g_slack;
			$channel_names = $g_slack->configs->get_value('g_channel_name');
			$bot_names = $g_slack->configs->get_value('g_bot_name');
			$emoji_names = $g_slack->configs->get_value('g_emoji_name');
			$events_notifies = $g_slack->configs->get_value('g_events_notify');
			$channel_notices = $g_slack->configs->get_value('g_channel_notice');
			$activated_arr = $g_slack->configs->get_value('g_activated');

			foreach ( $activated_arr as $k => $activated ) {
				if ( $activated == '1' && $events_notifies[$k] == GNA_SLACK_NOTIFICATION_LOGIN_LOCKDOWN ) {
					// get the current site url 
					$site_url = get_bloginfo('wpurl');
					
					// prepare a message to be posted to slack 
					$message = $username . ' from ' . $ip_range . '.* just locked down in ' . $site_url;

					if ( $channel_notices[$k] == '1' ) {
						$message = '<!channel|channel>: ' . $message;
					}

					GNA_Slack_Send::send_to_slack($message, $channel_names[$k], $bot_names[$k], $emoji_names[$k]);
				}
			}
		}

		static public function generate_event_notify_dropdown($selval = null) {
			$events_notify_arr = array(
										'Login' => GNA_SLACK_NOTIFICATION_LOGIN,
										'New Post' => GNA_SLACK_NOTIFICATION_NEW_POST,
										'New Comment' => GNA_SLACK_NOTIFICATION_NEW_COMMENT,
										'Login Lockdown' => GNA_SLACK_NOTIFICATION_LOGIN_LOCKDOWN,
									);
			$html_dropdown = '<select name="g_events_notify[]">';
			foreach ( $events_notify_arr as $k => $event ) {
				$html_dropdown .= '<option value="'.$event.'"'.($selval == $event ? "selected=\"selected\"" : "").'>'.$k.'</option>';
			}

			$html_dropdown .= '</select>';

			return $html_dropdown;
		}

		static public function generate_yesno_dropdown($name, $selval = null) {
			$arr = array(
						'Yes' => 1,
						'No' => 0,
					);
			$html_dropdown = '<select name="' . $name . '">';
			foreach ( $arr as $k => $v ) {
				$html_dropdown .= '<option value="'.$v.'"'.($selval == $v ? "selected=\"selected\"" : "").'>'.$k.'</option>';
			}
			
			$html_dropdown .= '</select>';

			return $html_dropdown;
		}

		public function install() {
		}

		public function uninstall() {
		}

		public function activate_handler() {
		}

		public function deactivate_handler() {
		}
	}
}
$GLOBALS['g_slack'] = new GNA_Slack();
